==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTextUI__24BasicHighlighter.h <==
// public class javax.swing.plaf.basic.BasicTextUI$BasicHighlighter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ac04aec46674864 javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter
// @dep_class 628a4e2547bd2153 javax_swing_text_DefaultHighlighter
// @dep_class 8004061994ba9184 javax_swing_text_LayeredHighlighter

// header file dependencies
// @dep_header javax_swing_text_DefaultHighlighter

#include "javax/swing/text/DefaultHighlighter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter$vmethods	javax_swing_text_LayeredHighlighter;
	_jc_javax_swing_text_DefaultHighlighter$vmethods	javax_swing_text_DefaultHighlighter;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
    _jc_javax_swing_text_DefaultHighlighter$sub_refs	javax_swing_text_DefaultHighlighter;
    _jc_javax_swing_text_LayeredHighlighter$sub_refs	javax_swing_text_LayeredHighlighter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	javax_swing_text_LayeredHighlighter;
    _jc_javax_swing_text_DefaultHighlighter$sub_nonrefs	javax_swing_text_DefaultHighlighter;
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTextUI__24BasicHighlighter.h <==
// public class javax.swing.plaf.basic.BasicTextUI$BasicHighlighter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ac04aec46674864 javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter
// @dep_class 628a4e2547bd2153 javax_swing_text_DefaultHighlighter
// @dep_class 8004061994ba9184 javax_swing_text_LayeredHighlighter

// header file dependencies
// @dep_header javax_swing_text_DefaultHighlighter

#include "javax/swing/text/DefaultHighlighter.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_
#define _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_LayeredHighlighter$vmethods	javax_swing_text_LayeredHighlighter;
	_jc_javax_swing_text_DefaultHighlighter$vmethods	javax_swing_text_DefaultHighlighter;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vmethods	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs {
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_refs	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
    _jc_javax_swing_text_DefaultHighlighter$sub_refs	javax_swing_text_DefaultHighlighter;
    _jc_javax_swing_text_LayeredHighlighter$sub_refs	javax_swing_text_LayeredHighlighter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_LayeredHighlighter$sub_nonrefs	javax_swing_text_LayeredHighlighter;
    _jc_javax_swing_text_DefaultHighlighter$sub_nonrefs	javax_swing_text_DefaultHighlighter;
    _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$sub_nonrefs	javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$object {
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$vtype _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTextUI__24BasicHighlighter_H_ */
